import aiohttp

from ..metistypes import Bot, BotRequest


class AsyncMetisUser:
    API_V1 = "https://api.metisai.ir/api/v1"

    def __init__(self, api_key):
        self.api_key = api_key
        self.endpoints = {
            "bots": f"{self.API_V1}/bots",
            "get_bot": f"{self.API_V1}/bots/{{bot_id}}",
        }
        self.headers = {
            "Content-Type": "application/json",
            "X-Api-Key": self.api_key,
        }
        self._session = None

    async def get_session(self):
        if self._session is None:
            self._session = aiohttp.ClientSession()
        return self._session

    async def _request(self, method: str, endpoint: str, **kwargs):
        url = self.endpoints.get(endpoint).format(
            **kwargs.get("url_params", {})
        )
        async with aiohttp.ClientSession() as session:
            async with session.request(
                method, url, headers=self.headers, **kwargs
            ) as response:
                response.raise_for_status()
                return await response.json()

    async def create_bot(self, bot_data: BotRequest):
        assert isinstance(bot_data, BotRequest)
        response_data = await self._request(
            method="POST", endpoint="bots", json=bot_data.model_dump()
        )
        return Bot(**response_data)

    async def retrieve_bot(self, bot_id: str):
        response_data = await self._request(
            method="GET", endpoint="get_bot", url_params={"bot_id": bot_id}
        )
        return response_data

    async def close(self):
        if self._session is not None:
            await self._session.close()
            self._session = None



import requests

from .metistypes import Bot, BotRequest


class MetisUser:
    API_V1 = "https://api.metisai.ir/api/v1"

    def __init__(self, api_key):
        self.api_key = api_key
        self.endpoints = {
            "bots": f"{self.API_V1}/bots",
            "get_bot": f"{self.API_V1}/bots/{{bot_id}}",
        }
        self.headers = {
            "Content-Type": "application/json",
            "X-Api-Key": self.api_key,
        }

    def create_bot(self, bot_data: BotRequest):
        assert isinstance(bot_data, BotRequest)
        response = requests.post(
            url=self.endpoints.get("bots"),
            headers=self.headers,
            json=bot_data.model_dump(),
        )
        return Bot(**response.json())

    def retrieve_bot(self, bot_id: str):
        response = requests.get(
            url=self.endpoints.get("get_bot").format(bot_id=bot_id),
            headers=self.headers,
        )
        return response.json()



import os
import time
import unittest

from metisai import MetisBot


class TestMetisBot(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super(self.__class__, self).__init__(*args, **kwargs)
        api_key = os.getenv("METIS_API_KEY")
        bot_id = os.getenv("METIS_BOT_ID")
        self.metisbot = MetisBot(api_key, bot_id)
        self.prompt = (
            "Suggest me a list of 5 gifts for a 30 years boy who is technology-fan."
        )

    def test_message(self):
        print()
        print("test_message")
        session = self.metisbot.create_session()
        message = self.metisbot.send_message(session, self.prompt)
        print(message.content)
        print()
        self.metisbot.delete_session(session)

    def test_session(self):
        print()
        print("test_session")
        session = self.metisbot.create_session()
        message = self.metisbot.send_message(session, self.prompt)
        print(message.content)
        prompt2 = "What if he is a book lover?"
        message2 = self.metisbot.send_message(session, prompt2)
        print(message2.content)
        print()
        self.metisbot.delete_session(session)

    def test_async_tasks(self):
        print()
        print("test_async_tasks")
        session = self.metisbot.create_session()
        task = self.metisbot.send_message_async(session, self.prompt)

        while True:
            task_result = self.metisbot.retrieve_async_task(session, task)
            if task_result.status == "FINISHED":
                break
            time.sleep(1)
        print(task_result.message.content)
        print()
        self.metisbot.delete_session(session)

    def test_stream_messages(self):
        print()
        print("test_stream_messages")
        session = self.metisbot.create_session()
        stream = self.metisbot.stream_messages(
            session, self.prompt, split_criteria={"line": True}
        )
        for message in stream:
            print(message.message.content)
        self.metisbot.delete_session(session)


if __name__ == "__main__":
    unittest.main()



import os
import re

from setuptools import find_packages, setup


def get_version(package):
    """
    Return package version as listed in `__version__` in `init.py`.
    """
    with open(os.path.join(package, "__init__.py")) as f:
        return re.search("__version__ = ['\"]([^'\"]+)['\"]", f.read()).group(
            1
        )


def get_long_description():
    """
    Return the README.
    """
    with open("README.md", encoding="utf8") as f:
        return f.read()


setup(
    name="metisai",
    version=get_version("metisai"),
    python_requires=">=3.7",
    url="https://github.com/mahdikiani/metisai",
    license="Apache-2.0",
    description="A Python client for Metis to streamline API interactions, enabling easy management and customization of AI-driven chatbots and image models.",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    author="Mahdi Kiani",
    author_email="mahdikiany@gmail.com",
    packages=find_packages(),
    zip_safe=False,
)
